@@ -99,6 +99,24 @@ class HAIR_MT_add_attribute(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -271,6 +289,24 @@ class HAIR_UL_attributes(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -454,6 +490,24 @@ class DATA_PT_context_hair(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -646,6 +700,24 @@ class DATA_PT_custom_props_hair(DataButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -832,6 +904,24 @@ class DATA_PT_hair_attributes(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
