@@ -3,6 +3,8 @@ import typing
 import bpy.types
 import mathutils
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class BMDeformVert:
     def clear(self):
@@ -21,26 +23,26 @@ class BMDeformVert:
         '''
         pass
 
-    def items(self) -> list:
+    def items(self) -> typing.List:
         ''' Return (group, weight) pairs for this vertex (matching pythons dict.items() functionality).
 
-        :rtype: list
+        :rtype: typing.List
         :return: (key, value) pairs for each deform weight of this vertex.
         '''
         pass
 
-    def keys(self) -> list:
+    def keys(self) -> typing.List[int]:
         ''' Return the group indices used by this vertex (matching pythons dict.keys() functionality).
 
-        :rtype: list
+        :rtype: typing.List[int]
         :return: the deform group this vertex uses
         '''
         pass
 
-    def values(self) -> list:
+    def values(self) -> typing.List[float]:
         ''' Return the weights of the deform vertex (matching pythons dict.values() functionality).
 
-        :rtype: list
+        :rtype: typing.List[float]
         :return: The weights that influence this vertex
         '''
         pass
@@ -235,7 +237,7 @@ class BMEdgeSeq:
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
-        :param fallback: 
+        :param fallback:  Return this value if nothing is found.
         :type fallback: 
         :rtype: 'BMEdge'
         :return: The edge found or None
@@ -248,13 +250,14 @@ class BMEdgeSeq:
         '''
         pass
 
-    def new(self, verts: 'BMVert', example: 'BMEdge' = None) -> 'BMEdge':
+    def new(self, verts: 'BMVert',
+            example: typing.Optional['BMEdge'] = None) -> 'BMEdge':
         ''' Create a new edge from a given pair of verts.
 
         :param verts: Vertex pair.
         :type verts: 'BMVert'
         :param example: Existing edge to initialize settings (optional argument).
-        :type example: 'BMEdge'
+        :type example: typing.Optional['BMEdge']
         :rtype: 'BMEdge'
         :return: The newly created edge.
         '''
@@ -282,10 +285,10 @@ class BMEditSelIter:
 
 
 class BMEditSelSeq:
-    active: typing.Union['BMVert', 'BMFace', 'BMEdge'] = None
+    active: 'BMVert' = None
     ''' The last selected element or None (read-only).
 
-    :type: typing.Union['BMVert', 'BMFace', 'BMEdge']
+    :type: 'BMVert'
     '''
 
     def add(self, element):
@@ -553,7 +556,7 @@ class BMFaceSeq:
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
-        :param fallback: 
+        :param fallback:  Return this value if nothing is found.
         :type fallback: 
         :rtype: 'BMFace'
         :return: The face found or None
@@ -566,13 +569,14 @@ class BMFaceSeq:
         '''
         pass
 
-    def new(self, verts: 'BMVert', example: 'BMFace' = None) -> 'BMFace':
+    def new(self, verts: 'BMVert',
+            example: typing.Optional['BMFace'] = None) -> 'BMFace':
         ''' Create a new face from a given set of verts.
 
         :param verts: Sequence of 3 or more verts.
         :type verts: 'BMVert'
         :param example: Existing face to initialize settings (optional argument).
-        :type example: 'BMFace'
+        :type example: typing.Optional['BMFace']
         :rtype: 'BMFace'
         :return: The newly created face.
         '''
@@ -765,18 +769,18 @@ class BMLayerCollection:
         '''
         pass
 
-    def items(self) -> list:
+    def items(self) -> typing.List:
         ''' Return the identifiers of collection members (matching pythons dict.items() functionality).
 
-        :rtype: list
+        :rtype: typing.List
         :return: (key, value) pairs for each member of this collection.
         '''
         pass
 
-    def keys(self) -> list:
+    def keys(self) -> typing.List[str]:
         ''' Return the identifiers of collection members (matching pythons dict.keys() functionality).
 
-        :rtype: list
+        :rtype: typing.List[str]
         :return: the identifiers for each member of this collection.
         '''
         pass
@@ -799,10 +803,10 @@ class BMLayerCollection:
         '''
         pass
 
-    def values(self) -> list:
+    def values(self) -> typing.List:
         ''' Return the values of collection (matching pythons dict.values() functionality).
 
-        :rtype: list
+        :rtype: typing.List
         :return: the members of this collection.
         '''
         pass
@@ -829,9 +833,9 @@ class BMLayerItem:
     def copy_from(self, other):
         ''' Return a copy of the layer
 
-        :param other: 
+        :param other:  Another layer to copy from.
         :type other: 
-        :param other: 
+        :param other:  BMLayerItem
         :type other: 
         '''
         pass
@@ -945,16 +949,16 @@ class BMLoop:
 
     def copy_from_face_interp(self,
                               face: 'BMFace',
-                              vert: bool = True,
-                              multires: bool = True):
+                              vert: typing.Optional[bool] = True,
+                              multires: typing.Optional[bool] = True):
         ''' Interpolate the customdata from a face onto this loop (the loops vert should overlap the face).
 
         :param face: The face to interpolate data from.
         :type face: 'BMFace'
         :param vert: When enabled, interpolate the loops vertex data (optional).
-        :type vert: bool
+        :type vert: typing.Optional[bool]
         :param multires: When enabled, interpolate the loops multires data (optional).
-        :type multires: bool
+        :type multires: typing.Optional[bool]
         '''
         pass
 
@@ -1151,12 +1155,13 @@ class BMVertSeq:
         '''
         pass
 
-    def new(self, co: float = (0.0, 0.0, 0.0),
+    def new(self,
+            co: typing.Optional[typing.Tuple[float]] = (0.0, 0.0, 0.0),
             example: 'BMVert' = None) -> 'BMVert':
         ''' Create a new vertex.
 
         :param co: The initial location of the vertex (optional argument).
-        :type co: float
+        :type co: typing.Optional[typing.Tuple[float]]
         :param example: Existing vert to initialize settings.
         :type example: 'BMVert'
         :rtype: 'BMVert'
@@ -1185,16 +1190,16 @@ class BMesh:
     ''' The BMesh data structure
     '''
 
-    edges: typing.Union[typing.List['BMEdge'], 'BMEdgeSeq'] = None
+    edges: typing.Union[typing.List['BMEdg'], 'BMEdgeSeq'] = None
     ''' This meshes edge sequence (read-only).
 
-    :type: typing.Union[typing.List['BMEdge'], 'BMEdgeSeq']
+    :type: typing.Union[typing.List['BMEdg'], 'BMEdgeSeq']
     '''
 
-    faces: typing.Union[typing.List['BMFace'], 'BMFaceSeq'] = None
+    faces: typing.Union[typing.List['BMFac'], 'BMFaceSeq'] = None
     ''' This meshes face sequence (read-only).
 
-    :type: typing.Union[typing.List['BMFace'], 'BMFaceSeq']
+    :type: typing.Union[typing.List['BMFac'], 'BMFaceSeq']
     '''
 
     is_valid: bool = None
@@ -1215,16 +1220,17 @@ class BMesh:
     :type: typing.Union[typing.List['BMLoop'], 'BMLoopSeq']
     '''
 
-    select_history: 'BMEditSelSeq' = None
+    select_history: typing.Union[typing.
+                                 List['BMEditSel'], 'BMEditSelSeq'] = None
     ''' Sequence of selected items (the last is displayed as active).
 
-    :type: 'BMEditSelSeq'
+    :type: typing.Union[typing.List['BMEditSel'], 'BMEditSelSeq']
     '''
 
-    select_mode: set = None
+    select_mode: typing.Set = None
     ''' The selection mode, values can be {'VERT', 'EDGE', 'FACE'}, can't be assigned an empty set.
 
-    :type: set
+    :type: typing.Set
     '''
 
     verts: typing.Union[typing.List['BMVert'], 'BMVertSeq'] = None
@@ -1331,12 +1337,12 @@ class BMesh:
         '''
         pass
 
-    def transform(self, matrix: 'mathutils.Matrix', filter: set = None):
+    def transform(self, matrix: 'mathutils.Matrix', filter: typing.Set = None):
         ''' Transform the mesh (optionally filtering flagged data only).
 
         :param matrix: transform matrix.
         :type matrix: 'mathutils.Matrix'
         :param filter: set of values in ('SELECT', 'HIDE', 'SEAM', 'SMOOTH', 'TAG').
-        :type filter: set
+        :type filter: typing.Set
         '''
         pass
