@@ -1,12 +1,23 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def attribute_add(name: str = "Attribute",
+def attribute_add(override_context: typing.
+                  Union[typing.Dict, 'bpy.types.Context'] = None,
+                  execution_context: typing.Union[str, int] = None,
+                  undo: bool = None,
+                  *,
+                  name: str = "Attribute",
                   domain: typing.Union[str, int] = 'POINT',
                   data_type: typing.Union[str, int] = 'FLOAT'):
     ''' Add attribute to geometry
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param name: Name, Name of new attribute
     :type name: str
     :param domain: Domain, Type of element that attribute is stored on * POINT Point -- Attribute on point. * EDGE Edge -- Attribute on mesh edge. * FACE Face -- Attribute on mesh faces. * CORNER Face Corner -- Attribute on mesh face corner. * CURVE Spline -- Attribute on spline.
@@ -18,9 +29,15 @@ def attribute_add(name: str = "Attribute",
     pass
 
 
-def attribute_remove():
+def attribute_remove(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: bool = None):
     ''' Remove attribute from geometry
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
