@@ -8,17 +8,17 @@ GenericType = typing.TypeVar("GenericType")
 def brush_edit(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               stroke: typing.Optional[bpy.types.bpy_prop_collection[
-                   'bpy.types.OperatorStrokeElement']] = None):
+               stroke: bpy.types.
+               bpy_prop_collection['bpy.types.OperatorStrokeElement'] = None):
     ''' Apply a stroke of brush to the particles
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param stroke: Stroke
-    :type stroke: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorStrokeElement']]
+    :type stroke: bpy.types.bpy_prop_collection['bpy.types.OperatorStrokeElement']
     '''
 
     pass
@@ -27,41 +27,40 @@ def brush_edit(override_context: typing.
 def connect_hair(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None,
+                 undo: bool = None,
                  *,
-                 all: typing.Union[bool, typing.Any] = False):
+                 all: bool = False):
     ''' Connect hair to the emitter mesh
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param all: All Hair, Connect all hair systems to the emitter mesh
-    :type all: typing.Union[bool, typing.Any]
+    :type all: bool
     '''
 
     pass
 
 
-def copy_particle_systems(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        space: typing.Optional[typing.Any] = 'OBJECT',
-        remove_target_particles: typing.Union[bool, typing.Any] = True,
-        use_active: typing.Union[bool, typing.Any] = False):
+def copy_particle_systems(override_context: typing.
+                          Union[typing.Dict, 'bpy.types.Context'] = None,
+                          execution_context: typing.Union[str, int] = None,
+                          undo: bool = None,
+                          *,
+                          space: typing.Union[str, int] = 'OBJECT',
+                          remove_target_particles: bool = True,
+                          use_active: bool = False):
     ''' Copy particle systems from the active object to selected objects
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param space: Space, Space transform for copying from one object to another * ``OBJECT`` Object, Copy inside each object's local space. * ``WORLD`` World, Copy in world space.
-    :type space: typing.Optional[typing.Any]
+    :type undo: bool
+    :param space: Space, Space transform for copying from one object to another * OBJECT Object -- Copy inside each object's local space. * WORLD World -- Copy in world space.
+    :type space: typing.Union[str, int]
     :param remove_target_particles: Remove Target Particles, Remove particle systems on the target objects
-    :type remove_target_particles: typing.Union[bool, typing.Any]
+    :type remove_target_particles: bool
     :param use_active: Use Active, Use the active particle system from the context
-    :type use_active: typing.Union[bool, typing.Any]
+    :type use_active: bool
     '''
 
     pass
@@ -70,16 +69,16 @@ def copy_particle_systems(
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           type: typing.Optional[typing.Any] = 'PARTICLE'):
+           type: typing.Union[str, int] = 'PARTICLE'):
     ''' Delete selected particles or keys
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type, Delete a full particle or only keys
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -88,35 +87,34 @@ def delete(override_context: typing.Union[typing.
 def disconnect_hair(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None,
+                    undo: bool = None,
                     *,
-                    all: typing.Union[bool, typing.Any] = False):
+                    all: bool = False):
     ''' Disconnect hair from the emitter mesh
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param all: All Hair, Disconnect all hair systems from the emitter mesh
-    :type all: typing.Union[bool, typing.Any]
+    :type all: bool
     '''
 
     pass
 
 
-def duplicate_particle_system(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        use_duplicate_settings: typing.Union[bool, typing.Any] = False):
+def duplicate_particle_system(override_context: typing.
+                              Union[typing.Dict, 'bpy.types.Context'] = None,
+                              execution_context: typing.Union[str, int] = None,
+                              undo: bool = None,
+                              *,
+                              use_duplicate_settings: bool = False):
     ''' Duplicate particle system within the active object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param use_duplicate_settings: Duplicate Settings, Duplicate settings as well, so the new particle system uses its own settings
-    :type use_duplicate_settings: typing.Union[bool, typing.Any]
+    :type use_duplicate_settings: bool
     '''
 
     pass
@@ -125,12 +123,12 @@ def duplicate_particle_system(
 def dupliob_copy(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
+                 undo: bool = None):
     ''' Duplicate the current instance object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -139,12 +137,12 @@ def dupliob_copy(override_context: typing.
 def dupliob_move_down(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: typing.Optional[bool] = None):
+                      undo: bool = None):
     ''' Move instance object down in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -153,12 +151,12 @@ def dupliob_move_down(override_context: typing.
 def dupliob_move_up(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None):
+                    undo: bool = None):
     ''' Move instance object up in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -167,12 +165,12 @@ def dupliob_move_up(override_context: typing.
 def dupliob_refresh(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None):
+                    undo: bool = None):
     ''' Refresh list of instance objects and their weights
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -181,12 +179,12 @@ def dupliob_refresh(override_context: typing.
 def dupliob_remove(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: typing.Optional[bool] = None):
+                   undo: bool = None):
     ''' Remove the selected instance object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -195,37 +193,36 @@ def dupliob_remove(override_context: typing.
 def edited_clear(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
+                 undo: bool = None):
     ''' Undo all edition performed on the particle system
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
 
 
-def hair_dynamics_preset_add(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        name: typing.Union[str, typing.Any] = "",
-        remove_name: typing.Union[bool, typing.Any] = False,
-        remove_active: typing.Union[bool, typing.Any] = False):
+def hair_dynamics_preset_add(override_context: typing.
+                             Union[typing.Dict, 'bpy.types.Context'] = None,
+                             execution_context: typing.Union[str, int] = None,
+                             undo: bool = None,
+                             *,
+                             name: str = "",
+                             remove_name: bool = False,
+                             remove_active: bool = False):
     ''' Add or remove a Hair Dynamics Preset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of the preset, used to make the path name
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     :param remove_name: remove_name
-    :type remove_name: typing.Union[bool, typing.Any]
+    :type remove_name: bool
     :param remove_active: remove_active
-    :type remove_active: typing.Union[bool, typing.Any]
+    :type remove_active: bool
     '''
 
     pass
@@ -234,16 +231,16 @@ def hair_dynamics_preset_add(
 def hide(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None,
+         undo: bool = None,
          *,
-         unselected: typing.Union[bool, typing.Any] = False):
+         unselected: bool = False):
     ''' Hide selected particles
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param unselected: Unselected, Hide unselected rather than selected
-    :type unselected: typing.Union[bool, typing.Any]
+    :type unselected: bool
     '''
 
     pass
@@ -252,12 +249,12 @@ def hide(override_context: typing.Union[typing.
 def mirror(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None):
+           undo: bool = None):
     ''' Duplicate and mirror the selected particles along the local X axis
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -266,12 +263,12 @@ def mirror(override_context: typing.Union[typing.
 def new(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Add new particle settings
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -280,12 +277,12 @@ def new(override_context: typing.Union[typing.
 def new_target(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None):
+               undo: bool = None):
     ''' Add a new particle target
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -294,12 +291,12 @@ def new_target(override_context: typing.
 def particle_edit_toggle(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: typing.Optional[bool] = None):
+                         undo: bool = None):
     ''' Toggle particle edit mode
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -308,16 +305,16 @@ def particle_edit_toggle(override_context: typing.
 def rekey(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: typing.Optional[bool] = None,
+          undo: bool = None,
           *,
-          keys_number: typing.Optional[typing.Any] = 2):
+          keys_number: int = 2):
     ''' Change the number of keys of selected particles (root and tip keys included)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param keys_number: Number of Keys
-    :type keys_number: typing.Optional[typing.Any]
+    :type keys_number: int
     '''
 
     pass
@@ -326,16 +323,16 @@ def rekey(override_context: typing.Union[typing.
 def remove_doubles(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: typing.Optional[bool] = None,
+                   undo: bool = None,
                    *,
-                   threshold: typing.Optional[typing.Any] = 0.0002):
+                   threshold: float = 0.0002):
     ''' Remove selected particles close enough of others
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param threshold: Merge Distance, Threshold distance within which particles are removed
-    :type threshold: typing.Optional[typing.Any]
+    :type threshold: float
     '''
 
     pass
@@ -344,16 +341,16 @@ def remove_doubles(override_context: typing.
 def reveal(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           select: typing.Union[bool, typing.Any] = True):
+           select: bool = True):
     ''' Show hidden particles
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param select: Select
-    :type select: typing.Union[bool, typing.Any]
+    :type select: bool
     '''
 
     pass
@@ -362,16 +359,16 @@ def reveal(override_context: typing.Union[typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               action: typing.Optional[typing.Any] = 'TOGGLE'):
+               action: typing.Union[str, int] = 'TOGGLE'):
     ''' (De)select all particles' keys
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle, Toggle selection for all elements. * ``SELECT`` Select, Select all elements. * ``DESELECT`` Deselect, Deselect all elements. * ``INVERT`` Invert, Invert selection of all elements.
-    :type action: typing.Optional[typing.Any]
+    :type undo: bool
+    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -380,12 +377,12 @@ def select_all(override_context: typing.
 def select_less(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Deselect boundary selected keys of each particle
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -394,12 +391,12 @@ def select_less(override_context: typing.
 def select_linked(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None):
+                  undo: bool = None):
     ''' Select all keys linked to already selected ones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -408,19 +405,19 @@ def select_linked(override_context: typing.
 def select_linked_pick(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: typing.Optional[bool] = None,
+                       undo: bool = None,
                        *,
-                       deselect: typing.Union[bool, typing.Any] = False,
-                       location: typing.Optional[typing.Any] = (0, 0)):
+                       deselect: bool = False,
+                       location: typing.List[int] = (0, 0)):
     ''' Select nearest particle from mouse pointer
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param deselect: Deselect, Deselect linked keys rather than selecting them
-    :type deselect: typing.Union[bool, typing.Any]
+    :type deselect: bool
     :param location: Location
-    :type location: typing.Optional[typing.Any]
+    :type location: typing.List[int]
     '''
 
     pass
@@ -429,12 +426,12 @@ def select_linked_pick(override_context: typing.
 def select_more(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Select keys linked to boundary selected keys of each particle
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -443,25 +440,25 @@ def select_more(override_context: typing.
 def select_random(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
+                  undo: bool = None,
                   *,
-                  ratio: typing.Optional[typing.Any] = 0.5,
-                  seed: typing.Optional[typing.Any] = 0,
-                  action: typing.Optional[typing.Any] = 'SELECT',
-                  type: typing.Optional[typing.Any] = 'HAIR'):
+                  ratio: float = 0.5,
+                  seed: int = 0,
+                  action: typing.Union[str, int] = 'SELECT',
+                  type: typing.Union[str, int] = 'HAIR'):
     ''' Select a randomly distributed set of hair or points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param ratio: Ratio, Portion of items to select randomly
-    :type ratio: typing.Optional[typing.Any]
+    :type ratio: float
     :param seed: Random Seed, Seed for the random number generator
-    :type seed: typing.Optional[typing.Any]
-    :param action: Action, Selection action to execute * ``SELECT`` Select, Select all elements. * ``DESELECT`` Deselect, Deselect all elements.
-    :type action: typing.Optional[typing.Any]
+    :type seed: int
+    :param action: Action, Selection action to execute * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements.
+    :type action: typing.Union[str, int]
     :param type: Type, Select either hair or points
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -470,16 +467,16 @@ def select_random(override_context: typing.
 def select_roots(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None,
+                 undo: bool = None,
                  *,
-                 action: typing.Optional[typing.Any] = 'SELECT'):
+                 action: typing.Union[str, int] = 'SELECT'):
     ''' Select roots of all visible particles
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle, Toggle selection for all elements. * ``SELECT`` Select, Select all elements. * ``DESELECT`` Deselect, Deselect all elements. * ``INVERT`` Invert, Invert selection of all elements.
-    :type action: typing.Optional[typing.Any]
+    :type undo: bool
+    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -488,16 +485,16 @@ def select_roots(override_context: typing.
 def select_tips(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None,
+                undo: bool = None,
                 *,
-                action: typing.Optional[typing.Any] = 'SELECT'):
+                action: typing.Union[str, int] = 'SELECT'):
     ''' Select tips of all visible particles
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle, Toggle selection for all elements. * ``SELECT`` Select, Select all elements. * ``DESELECT`` Deselect, Deselect all elements. * ``INVERT`` Invert, Invert selection of all elements.
-    :type action: typing.Optional[typing.Any]
+    :type undo: bool
+    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -506,12 +503,12 @@ def select_tips(override_context: typing.
 def shape_cut(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: typing.Optional[bool] = None):
+              undo: bool = None):
     ''' Cut hair to conform to the set shape object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -520,12 +517,12 @@ def shape_cut(override_context: typing.Union[typing.
 def subdivide(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: typing.Optional[bool] = None):
+              undo: bool = None):
     ''' Subdivide selected particles segments (adds keys)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -534,12 +531,12 @@ def subdivide(override_context: typing.Union[typing.
 def target_move_down(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None):
+                     undo: bool = None):
     ''' Move particle target down in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -548,12 +545,12 @@ def target_move_down(override_context: typing.
 def target_move_up(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: typing.Optional[bool] = None):
+                   undo: bool = None):
     ''' Move particle target up in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -562,12 +559,12 @@ def target_move_up(override_context: typing.
 def target_remove(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None):
+                  undo: bool = None):
     ''' Remove the selected particle target
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -576,12 +573,12 @@ def target_remove(override_context: typing.
 def unify_length(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
+                 undo: bool = None):
     ''' Make selected hair the same length
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -590,16 +587,16 @@ def unify_length(override_context: typing.
 def weight_set(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               factor: typing.Optional[typing.Any] = 1.0):
+               factor: float = 1.0):
     ''' Set the weight of selected keys
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param factor: Factor, Interpolation factor between current brush weight, and keys' weights
-    :type factor: typing.Optional[typing.Any]
+    :type factor: float
     '''
 
     pass
