@@ -4,6 +4,8 @@ import freestyle.types
 import bpy.types
 import mathutils
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class BackboneStretcherShader:
     ''' Class hierarchy: freestyle.types.StrokeShader > BackboneStretcherShader [Geometry shader]
@@ -51,12 +53,11 @@ class BlenderTextureShader:
     ''' Class hierarchy: freestyle.types.StrokeShader > BlenderTextureShader [Texture shader]
     '''
 
-    def __init__(self, texture: typing.Union[
-            'bpy.types.ShaderNodeTree', 'bpy.types.LineStyleTextureSlot']):
+    def __init__(self, texture: 'bpy.types.LineStyleTextureSlot'):
         ''' Builds a BlenderTextureShader object.
 
         :param texture: A line style texture slot or a shader node tree to define a set of textures.
-        :type texture: typing.Union['bpy.types.ShaderNodeTree', 'bpy.types.LineStyleTextureSlot']
+        :type texture: 'bpy.types.LineStyleTextureSlot'
         '''
         pass
 
