@@ -32,13 +32,7 @@ class IDPropertyGroup:
         pass
 
     def items(self):
-        ''' Return the items associated with this group.
-
-        '''
-        pass
-
-    def iteritems(self):
-        ''' Iterate through the items in the dict; behaves like dictionary method iteritems.
+        ''' Iterate through the items in the dict; behaves like dictionary method items.
 
         '''
         pass
@@ -49,13 +43,13 @@ class IDPropertyGroup:
         '''
         pass
 
-    def pop(self, key: str, default: typing.Any):
+    def pop(self, key: str, default):
         ''' Remove an item from the group, returning a Python representation. :raises KeyError: When the item doesn't exist.
 
         :param key: Name of item to remove.
         :type key: str
         :param default: Value to return when key isn't found, otherwise raise an exception.
-        :type default: typing.Any
+        :type default: 
         '''
         pass
 
@@ -65,11 +59,11 @@ class IDPropertyGroup:
         '''
         pass
 
-    def update(self, other: typing.Union['IDPropertyGroup', typing.Dict]):
+    def update(self, other: 'IDPropertyGroup'):
         ''' Update key, values.
 
         :param other: Updates the values in the group with this.
-        :type other: typing.Union['IDPropertyGroup', typing.Dict]
+        :type other: 'IDPropertyGroup'
         '''
         pass
 
@@ -80,5 +74,25 @@ class IDPropertyGroup:
         pass
 
 
-class IDPropertyGroupIter:
+class IDPropertyGroupIterItems:
+    pass
+
+
+class IDPropertyGroupIterKeys:
+    pass
+
+
+class IDPropertyGroupIterValues:
+    pass
+
+
+class IDPropertyGroupViewItems:
+    pass
+
+
+class IDPropertyGroupViewKeys:
+    pass
+
+
+class IDPropertyGroupViewValues:
     pass
