@@ -19,11 +19,10 @@ def load(filepath: str) -> 'imbuf.types.ImBuf':
     pass
 
 
-def new(size: typing.Any) -> 'imbuf.types.ImBuf':
+def new(size) -> 'imbuf.types.ImBuf':
     ''' Load a new image.
 
     :param size: The size of the image in pixels.
-    :type size: typing.Any
     :rtype: 'imbuf.types.ImBuf'
     :return: the newly loaded image.
     '''
@@ -31,12 +30,12 @@ def new(size: typing.Any) -> 'imbuf.types.ImBuf':
     pass
 
 
-def write(image: 'imbuf.types.ImBuf', filepath: str):
+def write(image: 'imbuf.types.ImBuf', filepath: str = 'image.filepath'):
     ''' Write an image.
 
     :param image: the image to write.
     :type image: 'imbuf.types.ImBuf'
-    :param filepath: the filepath of the image.
+    :param filepath: Optional filepath of the image (fallback to the images file path).
     :type filepath: str
     '''
 
